changeset 13342:bd981bf1a663

[gaim-migrate @ 15712] SF Patch #1439221 from Shawn Outman "The fix that allowed the message window to blink with the first message in the conversation also allowed it to blink with system messages, including those from the Buddy State Notification plugin. This patch modifies winprefs to not flash for system messages, which is how it is in 1.5 and 2.0beta1 & 2. (The first message in the conversation still causes it to blink, however)." committer: Tailor Script <tailor@pidgin.im>
author Richard Laager <rlaager@wiktel.com>
date Tue, 28 Feb 2006 01:27:12 +0000
parents 42e6c5e038d8
children 3e87f0c5287d
files COPYRIGHT plugins/win32/winprefs/winprefs.c
diffstat 2 files changed, 3 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/COPYRIGHT	Mon Feb 27 22:59:45 2006 +0000
+++ b/COPYRIGHT	Tue Feb 28 01:27:12 2006 +0000
@@ -196,6 +196,7 @@
 Ruediger Oertel
 Gudmundur Bjarni Olafsson
 Bartosz Oler
+Shawn Outman
 Nathan Owens (pianocomp81)
 John Oyler
 Matt Pandina
--- a/plugins/win32/winprefs/winprefs.c	Mon Feb 27 22:59:45 2006 +0000
+++ b/plugins/win32/winprefs/winprefs.c	Tue Feb 28 01:27:12 2006 +0000
@@ -288,8 +288,8 @@
 	GaimGtkWindow *win;
 	GtkWidget *window;
 
-	/* Don't flash for our own messages */
-	if(flags & GAIM_MESSAGE_SEND)
+	/* Don't flash for our own messages or system messages */
+	if(flags & GAIM_MESSAGE_SEND || flags & GAIM_MESSAGE_SYSTEM)
 		return FALSE;
 
 	if(!gaim_prefs_get_bool(PREF_IM_BLINK))